window.Gleam.initSearch([{"doc":"gcalc","title":"gcalc","content":"# gcalc\n\n[![Package Version](https://img.shields.io/hexpm/v/gcalc)](https://hex.pm/packages/gcalc)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gcalc/)\n\nA pure gleam library for mathematical calculations.\n```sh\ngleam add gcalc\n```\n```gleam\nimport gleam/io\nimport gcalc\n\npub fn main() {\n  let x = 2.0\n  let y = 4.0\n  let z = alg.pow(x, y)\n\n  io.debug(z)\n  // Ok(16.0)\n\n  gcalc.sqrt(z)\n  |&gt; io.debug\n  // Ok(4.000000000000051)\n\n  alg.factorial(y)\n  |&gt; io.debug\n  // Ok(24.0)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gcalc&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"gcalc","title":"MathError","content":"pub type MathError {\n  DivisionByZero\n  ValueOutOfRange\n  UnsupportedOperation\n}\n MathError represents an error that can occur when performing\n a mathematical operation\nDivisionByZero\n\n\nValueOutOfRange\n\n\nUnsupportedOperation\n\n\nSynonyms:\ngcalc.MathError\ngcalc MathError","url":"gcalc.html#MathError"},{"doc":"gcalc","title":"abs","content":"pub fn abs(n: Float) -&gt; Float\n Returns the absolute value of the argument\nSynonyms:\ngcalc.abs\ngcalc abs","url":"gcalc.html#abs"},{"doc":"gcalc","title":"cbrt","content":"pub fn cbrt(n: Float) -&gt; Result(Float, MathError)\n Returns a result containing the cube root of the argument\n\n Note: This function only supports non-negative values\nSynonyms:\ngcalc.cbrt\ngcalc cbrt","url":"gcalc.html#cbrt"},{"doc":"gcalc","title":"factorial","content":"pub fn factorial(n: Float) -&gt; Result(Float, MathError)\n Returns a result containing the factorial of the argument\n or an error if the argument is negative\n\n Note: This function only supports non-negative values\nSynonyms:\ngcalc.factorial\ngcalc factorial","url":"gcalc.html#factorial"},{"doc":"gcalc","title":"pow","content":"pub fn pow(base: Float, power: Float) -&gt; Float\n Returns the exponentiation of the two arguments\n (i.e. the first argument raised to the power of the second argument)\n\n Example:\n \n let base = 2.0\n let power = 3.0\n pow(base, power) // 8.0\n \nSynonyms:\ngcalc.pow\ngcalc pow","url":"gcalc.html#pow"},{"doc":"gcalc","title":"pow10","content":"pub fn pow10(n: Float) -&gt; Result(Float, MathError)\n Returns a result containing 10^n where n is the argument\nSynonyms:\ngcalc.pow10\ngcalc pow10","url":"gcalc.html#pow10"},{"doc":"gcalc","title":"pow2","content":"pub fn pow2(n: Float) -&gt; Result(Float, MathError)\n Returns a result containing 2^n where n is the argument\nSynonyms:\ngcalc.pow2\ngcalc pow2","url":"gcalc.html#pow2"},{"doc":"gcalc","title":"sqrt","content":"pub fn sqrt(n: Float) -&gt; Result(Float, MathError)\n Returns a result containing the square root of the argument\n or an error if the argument is negative\n\n Note: This function only supports non-negative values\n\n Example:\n \n sqrt(4.0)             // Ok(2.000000000000002)\n |&gt; result.unwrap(0.0) // 2.000000000000002\n |&gt; float.floor        // 2.0\n \nSynonyms:\ngcalc.sqrt\ngcalc sqrt","url":"gcalc.html#sqrt"},{"doc":"gcalc","title":"gcalc","content":" A set of algebraic operations for Gleam programs","url":"gcalc.html"}]);